# Swack Multimedia

## Install

```shell
pip install swack-multimedia
```

## Usage

```Python3
from swack.video import VideoOverview

vo = VideoOverview(video="test_video.mp4", w=5, h=8)
vo.run()
```
